==> slapos.cookbook-0.56-dev.tar.gz: slapos.cookbook-0.56-dev/slapos/recipe/slapreport/__init__.py <==
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):
  """
  Slapmonitor instance configuration.
  """

  def __init__(self, buildout, name, options):
    return GenericBaseRecipe.__init__(self, buildout, name, options)

  def install(self):
    config = dict(
      pid_file_path=self.options['pid-file'],
      consumption_log_path=self.options['consumption-log-path'],
      database_path=self.options['database-path'],
      slapreport_path = self.options['slapreport-path'],
      logbox_ip = self.options['logbox-ip'],
      logbox_port = self.options['logbox-port'],
      logbox_user = self.options['logbox-user'],
      logbox_passwd = self.options['logbox-passwd'],
      shell_path=self.options['shell-path'],
    )

    # Runners
    runner_path = self.createExecutable(
      self.options['path'],
      self.substituteTemplate(self.getTemplateFilename('slapreport_run.in'),
                              config))

    return [runner_path]

  def update(self):
    pass

==> slapos.cookbook-0.71.tar.gz: slapos.cookbook-0.71/slapos/recipe/slapreport/__init__.py <==
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def install(self):
    options = self.options
    script = self.createWrapper(name=options['path'],
                                command=options['slapreport-path'],
                                parameters=[
                                    options['pid-file'],
                                    options['consumption-log-path'],
                                    options['database-path'],
                                    options['logbox-ip'],
                                    options['logbox-port'],
                                    options['logbox-user'],
                                    options['logbox-passwd'],
                                    ])
    return [script]
